SignatureController class

Inheritance

Constructors

SignatureController({required Color penColor, double strokeWidth = 2.0, Color? exportPenColor, Color? exportBackgroundColor})

Properties

exportBackgroundColor Color
getter/setter pair
exportPenColor Color
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
isEmpty bool
no setter
penColor Color
getter/setter pair
points List<SignaturePoint?>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
strokeWidth double
getter/setter pair

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
addPoint(Offset offset) → void
clear() → void
dispose() → void
Discards any resources used by the object. After this is called, the object is not in a usable state and should be discarded (calls to addListener will throw after the object is disposed).
inherited
endStroke() → void
exportAsImage({Color? penColor, Color? backgroundColor, double? strokeWidthOverride, Size size = const Size(600, 300)}) Future<Uint8List?>
Exporta como imagen PNG en memoria
exportAsJson() List<Map<String, dynamic>?>
Exporta puntos como JSON (lista de mapas)
exportAsJsonBase64() String
Exporta puntos como JSON codificado en base64
exportAsPngBase64({Color? penColor, Color? backgroundColor, Size size = const Size(600, 300)}) Future<String?>
Exporta imagen como base64
importFromJson(List jsonList) → void
Importa puntos desde JSON (lista de mapas)
importFromJsonBase64(String base64String) → void
Importa puntos desde JSON en base64
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited